# Release notes for MUSE v1.4.3 (June 25, 2025)

These are the main changes in MUSE v1.4.3.

## Small change to the calculation of commodity prices ({github}`728`)

- Fixes an issue where prices would sometimes rise to extremely high levels cause by under-utilized assets
- See {github}`728` for more details

## Small change to the carbon budget algorithm to prevent extremely high carbon prices ({github}`733`)

- A new parameter called `price_penalty` has been introduced, which aims to limit carbon price rises in scenarios where the carbon budget cannot be reached
- Please see documentation [here](https://muse-os.readthedocs.io/en/latest/inputs/toml.html#carbon-market), and see {github}`733` for more details

## Removed "Fuel", "EndUse" and ""ScalingSize" parameters from technodata files ({github}`715` and {github}`729`)

- These parameters are either not required, or can be inferred from other input data (e.g. commodity in/out data)
- A deprecation warning will be raised if any of these columns are present in your technodata files
